Build or update the flights database for a site, normally called by
screen; call if you're unable or unwilling to run screen.
Arguments
- site
Site abbreviation
- update
If TRUE, update file timestamps rather than deleting newer files from database. Use this to preserve scores, comments, etc. when replacing all files.
- refresh
Recreated database from scratch. Warning: this will destroy your existing database, including all assigned scores and comments. Requires also supplying
really = TRUE.- really
If TRUE, allows refresh to recreate the database
Details
Reads any existing flights_pars.yml as
case-insensitive underscore-separated words (after applying name fixes).
Only flights that have not been deleted are returned.
Files with changed timestamps are presumed to have been re-downloaded with gather (as stamps are set in processing). Files shouldn't be re-downloaded and replaced unless they've changed on the source, so these files have presumable been repaired. They are refreshed in the flights database, ready for re-screening.